.. currentmodule:: pyfits

.. _Images:

******
Images
******

.. inheritance-diagram:: Section ImageHDU

`ImageHDU`
==========

.. autoclass:: ImageHDU
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:

`CompImageHDU`
==============

.. autoclass:: CompImageHDU
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:

`Section`
=========

.. autoclass:: Section
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:

